@@ -4,9 +4,9 @@ Copyright (C) 1994, 1996, 1999, 2000
 
 Author: Hironobu Takahashi, Masahiko Sato, Kiyotaka Sakai, Kenji Yabuuchi
 Maintainer: Mikio Nakajima <minakaji@osaka.email.ne.jp>
-Version: $Id: skkdic-expr.c,v 1.8 2000/12/15 10:04:50 minakaji Exp $
+Version: $Id: skkdic-expr.c,v 1.10 2006/01/04 10:35:06 skk-cvs Exp $
 Keywords: japanese
-Last Modified: $Date: 2000/12/15 10:04:50 $
+Last Modified: $Date: 2006/01/04 10:35:06 $
 
 This file is part of Daredevil SKK.
 
@@ -22,7 +22,8 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with SKK; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+the Free Software Foundation,  Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA. */
 
 /* skkdic-expr.c
    Υץ SKK μΥޡԤޤ
@@ -84,7 +85,7 @@ extern int errno;
 #ifdef MAXLINE
 #define BLEN MAXLINE
 #else
-#define BLEN 4096
+#define BLEN 65536
 #endif
 
 /* ѥե̾ */
